home · contact · privacy
Fixed README typo.
[plomrogue] / src / map.h
index ac303a40036fe3660938c015cf9a33fb6fcda5b9..73825c0446845b051fc2eacd3380a8ba07f391f8 100644 (file)
--- a/src/map.h
+++ b/src/map.h
@@ -9,8 +9,7 @@
 
 
 #include "yx_uint16.h" /* for yx_uint16 and dir enums */
-struct Player;
-
+struct MapObj;
 
 
 struct Map
@@ -38,10 +37,10 @@ extern struct Map init_map();
  */
 extern void map_scroll(struct Map * map, enum dir d, struct yx_uint16 win_size);
 
/* Scroll map to center on the player by changing the scroll offset following
  * (and constrained by) the window size as described by "win_size".
  */
-extern void map_center_player(struct Map * map, struct Player * player,
+extern void map_center_object(struct Map * map, struct MapObj * object,
                               struct yx_uint16 win_size);
@@ -38,10 +37,10 @@ extern struct Map init_map();
 extern void map_scroll(struct Map * map, enum dir d, struct yx_uint16 win_size);
 
-/* Scroll map to center on the player by changing the scroll offset following
+/* Scroll map to center on the "object" by changing the scroll offset following
  * (and constrained by) the window size as described by "win_size".
  */